@@ -140,19 +140,13 @@ from unittest import TextTestResult
 from sysconfig import get_platform
 
 import setuptools
-import pkg_resources
 
 # We need to be able to test BDB releases, even if the license is incompatible
 os.environ['YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION'] = ''
 
 
 PROGRAM = sys.argv[0]
-min_version = pkg_resources.parse_version('62.1.0')
-if pkg_resources.parse_version(setuptools.__version__) >= min_version:
-    PLAT_SPEC = f'{get_platform()}-{sys.implementation.cache_tag}'
-else:
-    version = sys.version_info
-    PLAT_SPEC = f'{get_platform()}-{version.major}.{version.minor}'
+PLAT_SPEC = f'{get_platform()}-{sys.implementation.cache_tag}'
 
 # This hack copied from distutils.command.build.  Too bad distutils
 # doesn't export its build/ directory naming scheme as a library function.
