@@ -1,5 +1,5 @@
 """
-Copyright (c) 2008-2022, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2023, Jesus Cea Avion <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -79,14 +79,14 @@ def print_versions():
 
     # Workaround for allowing generating an EGGs as a ZIP files.
     suffix="__"
-    print('py module:            %s' % getattr(berkeleydb, "__file"+suffix))
-    print('extension module:     %s' % getattr(berkeleydb, "__file"+suffix))
+    print('py module:           %s' % getattr(berkeleydb, "__file"+suffix))
+    print('extension module:    %s' % getattr(berkeleydb._db, "__file"+suffix))
 
-    print('Test working dir:     %s' % get_test_path_prefix())
-    print('python version:       %s %s' % \
+    print('Test working dir:    %s' % get_test_path_prefix())
+    print('python version:      %s %s' % \
             (sys.version.replace("\r", "").replace("\n", ""), \
             platform.architecture()[0]))
-    print('My pid:               %s' % os.getpid())
+    print('My pid:              %s' % os.getpid())
     print('-=' * 38)
 
 
@@ -148,6 +148,20 @@ class PrintInfoFakeTest(unittest.TestCase):
     def testPrintVersions(self):
         print_versions()
 
+class pathTest(unittest.TestCase):
+    def test_path(self):
+        path_dir = pathlib.Path(os.environ.get('BERKELEYDB_SO_PATH', None))
+        self.assertIsNotNone(path_dir)
+        path_dir = path_dir.resolve()
+        path_file = pathlib.Path(berkeleydb._db.__file__).resolve()
+        if sys.version_info >= (3, 9):
+            self.assertTrue(path_file.is_relative_to(path_dir),
+                    msg=f"Wrong library: '{path_file}' not in '{path_dir}'")
+        else:
+            path_dir = path_dir.as_posix()
+            path_file = path_file.as_posix()
+            self.assertEqual(path_dir, path_file[:len(path_dir)])
+
 
 def suite(module_prefix='', timing_check=None):
     test_modules = [
@@ -195,7 +209,7 @@ def suite(module_prefix='', timing_check=None):
 
 def test_suite():
     suite = unittest.TestSuite()
-    for test in (PrintInfoFakeTest,):
+    for test in (PrintInfoFakeTest, pathTest):
         test = unittest.defaultTestLoader.loadTestsFromTestCase(test)
         suite.addTest(test)
     return suite
